#!/bin/bash

source /etc/asl/config

# Legacy AR for v5 only
if [ ! -f /var/asl/lib/firewall-functions ]; then
	exit 
fi
source /var/asl/lib/firewall-functions

IPSET_NAME=ASL-ACTIVE-RESPONSE
ACTION=$1
USER=$2
IP=$3
COMMENT=$4

LOCAL=`dirname $0`;
cd $LOCAL
cd ../
filename=$(basename "$0")

LOG_FILE="${PWD}/../logs/active-responses.log"

echo "`date` $0 $1 $2 $3 $4 $5" >> ${LOG_FILE}

# Checking for an IP
if [ "x${IP}" = "x" ]; then
	echo "$0: <action> <username> <ip>" 
	exit 1
fi

# Test for IPSET support
if [ $IPSETS -ne 1 ]; then
	exit 1
fi

# Checking for invalid entries (lacking ".", etc)
echo "${IP}" | grep "\." > /dev/null 2>&1
if [ ! $? = 0 ]; then
    echo "`date` Invalid ip/hostname entry: ${IP}" >> ${PWD}/../logs/active-responses.log
    exit 1;
fi

#dont add localhost
echo "${IP}" | egrep "^127.|localhost|localhost.localdomain" > /dev/null 2>&1
if [ $? = 0 ]; then
    echo "`date` Illegal ip/hostname entry: ${IP}" >> ${PWD}/../logs/active-responses.log
    exit 1;
fi

#check that its an IP
echo "${IP}" | egrep "^([0-9]{1,3})[.]([0-9]{1,3})[.]([0-9]{1,3})[.]([0-9]{1,3})$" > /dev/null 2>&1
if [ ! $? = 0 ]; then
    echo "`date` Illegal use of hostname entry: ${IP}" >> ${PWD}/../logs/active-responses.log
    exit 1;
fi


EXPIRE=""
if [[ $OSSEC_SHUN_TIME =~ ^-?[0-9]+$ ]]; then
	EXPIRE="timeout $OSSEC_SHUN_TIME"
fi

if ! $IPSET list -n $IPSET_NAME >/dev/null 2>&1; then
	$IPSET create $IPSET_NAME hash:ip $EXPIRE
fi

# removed to prevent duplication when a shun is added while the firewall is being restarted
#if ! ${IPTABLES} -L INPUT  | grep -q "match-set ASL-ACTIVE-RESPONSE" ; then
#	${IPTABLES} -I INPUT -m set --match-set ASL-ACTIVE-RESPONSE src -j DROP
#fi

if [ "x${ACTION}" = "xadd" ]; then
	#$IPSET add $IPSET_NAME $IP -exist $EXPIRE
	$IPSET add $IPSET_NAME $IP -exist 
fi

if [ "x${ACTION}" = "xdelete" ]; then
	$IPSET del $IPSET_NAME $IP -exist 
fi


