#!/bin/sh
# Cloudflare API supports
#Cloudflare Client V4
#

source /etc/asl/config

if [ "$HIDS_CLOUDFLARE_BAN" != "yes" ]; then
	exit;
fi

ACTION=$1
USER=$2
IP=$3
ALERTID=$4
PWD=`pwd`
LOG_FILE="/var/ossec/logs/active-responses.log"
CURL=/usr/bin/curl
# old API
#URL="https://www.cloudflare.com/api_json.html"
URL="https://api.cloudflare.com/client/v4"
API_FILE="/etc/asl/cl_clientapi"


LOCAL=`dirname $0`;
cd $LOCAL
cd ../
filename=$(basename "$0")

# Log
echo "`date` $0 $1 $2 $3 $4 $5" >>  ${LOG_FILE}

# Checking for an IP
if [ "x${IP}" = "x" ]; then
   echo "$0: <action> <username> <ip>" 
   exit 1;
fi

# Blocking IP
if [ "x${ACTION}" != "xadd" -a "x${ACTION}" != "xdelete" ]; then
   echo "$0: invalid action: ${ACTION}"
   exit 1;
fi

# loop through known email/api keys
while read line; do
  arrLine=(${line//,/ })

  # old API
  # Add the IP
  #if [ "x${ACTION}" = "xadd" ]; then
  #   $CURL $URL -d 'a=ban' -d 'key='${IP} -d 'tkn='${arrLine[1]} -d 'email='${arrLine[0]}
  # Delete the IP
  #else
  #   $CURL $URL -d 'a=nul' -d 'key='${IP} -d 'tkn='${arrLine[1]} -d 'email='${arrLine[0]}
  #fi

  # Add the IP
  if [ "x${ACTION}" = "xadd" ]; then
    $CURL -s -X POST "${URL}/user/firewall/access_rules/rules" -H "X-Auth-Email: ${arrLine[0]}" -H "X-Auth-Key: ${arrLine[1]}" -H "Content-Type: application/json" --data '{"mode":"block","configuration":{"target":"ip","value":"'$IP'","notes":"blocked by ASL"}}'
  # Delete the IP
  else
    RET=$($CURL -sSX GET "${URL}/user/firewall/access_rules/rules?mode=block&configuration_target=ip&configuration_value=${IP}" -H "X-Auth-Email: ${arrLine[0]}" -H "X-Auth-Key: ${arrLine[1]}" -H "Content-Type: application/json")
	

    ID=$(echo $RET | jq -r '.result[].id')
	
	
    $CURL -s -X DELETE "${URL}/user/firewall/access_rules/rules/${ID}" -H "X-AUTH-EMAIL: ${arrLine[0]}" -H "X-Auth-Key: ${arrLine[1]}" -H "Content-Type: application/json"
	
  fi
done < $API_FILE


# Add
#if [ "x${ACTION}" = "xadd" ]; then
#	$CURL $URL -d 'a=ban' -d 'key='${IP} -d 'tkn='${HIDS_CLOUDFLARE_BAN_API} -d 'email='${HIDS_CLOUDFLARE_BAN_EMAIL}
# Delete
#else
#	$CURL $URL -d 'a=nul' -d 'key='${IP} -d 'tkn='${HIDS_CLOUDFLARE_BAN_API} -d 'email='${HIDS_CLOUDFLARE_BAN_EMAIL}
#fi


