#!/usr/bin/python

import random
import requests
import ecoapi
import sys
from datetime import datetime

# Suppress warnings
import urllib3
urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
import json

def main():
    # ossec supplied params
    action = sys.argv[1]
    dstuser = sys.argv[2]
    srcip = sys.argv[3]

    # load api creds from asl config file
    username = ""
    password = ""
    port = ""
    hostname = ""
    with open("/etc/asl/config") as file:
        for line in file:
            if "HIDS_UNISYS_STEALTH_API_USERNAME" in line:
                username = line.split("=")[1].strip("\n").strip("\"")
            if "HIDS_UNISYS_STEALTH_API_PASSWORD" in line:
                password = line.split("=")[1].strip("\n").strip("\"")
            if "HIDS_UNISYS_STEALTH_API_HOSTNAME" in line:
                hostname = line.split("=")[1].strip("\n").strip("\"")
            if "HIDS_UNISYS_STEALTH_API_PORT" in line:
                port = line.split("=")[1].strip("\n").strip("\"")


    auth=(username, password)

    # some http request settings
    base_uri = 'https://{}:{}/uisStealth/EcoAPI/latest'.format(hostname, port)
    session_uri = base_uri + "/session"
    quarantine_uri = session_uri + "/quarantine"
    headers = {'accept': 'application/json'}
    params = {}

    # quarantine list
    QUARANTINE_LIST = "/var/asl/data/stealth-quarantine.txt"

    # quarantine a user
    if action == "add":
        request_status = requests.get(session_uri, auth=auth, headers=headers, verify=False)
        response = ecoapi.check_error(request_status)

        sessions = response['session']
        data = json.loads(json.dumps(response))

        params["undo"] = "false"
        for session in data['session']:
            if session['ipAddress'] == srcip:
                params["user"] = user

                # log it
                fh = open(QUARANTINE_LIST, "a+")
                fh.write(session['ipAddress']+":"+session['domainUser']+"\n")
                fh.close()
                break

        response = requests.post(quarantine_uri, auth=auth, params=params, headers=headers, verify=False)


    # unquarantine a user
    if action == "delete":
        params["undo"]="true"

        # grab user from quarantine file
        fh = open(QUARANTINE_LIST, "r")
        for line in fh.readlines():
           parts = line.split(":")
           if parts[0] == srcip:
               params["user"] = parts[1].strip('\n')
               break

        response = requests.post(quarantine_uri, auth=auth, params=params, headers=headers, verify=False)


    #Logging
    f = open("/var/ossec/logs/active-responses.log", "a")
    date = datetime.utcnow()
    logStr = date.strftime('%a %b %d %H:%M:%S %Y') + " " + sys.argv[0] + " " + action + " " + dstuser + " " + srcip + "\n"
    f.write(logStr)
    f.close()

ecoapi.invoke_api(main)
